@@ -3,7 +3,6 @@
 #' @param x Covariates.
 #' @param p0  Cut-off P-value. 
 #' @param km The maximum number of selected covariates for each node irrespective of cut-off P-value.
-#' @param kmx The maximum number of selected covariates for each node for given cut-off P-value.
 #' @param nu The order statistic of Gaussian covariates used for comparison.
 #' @param nedge The maximum number of edges.
 #' @param inr Logical if TRUE include an intercept.
@@ -11,7 +10,7 @@
 #' @return edg List of edges
 #' data(boston)
 #' a<-fgr1st(boston[,1:13]) 
-fgr1st<-function(x,p0=0.01,km=0,kmx=0,nu=1,nedge=10^6,inr=T,dr=F){
+fgr1st<-function(x,p0=0.01,km=0,nu=1,nedge=10^6,inr=T,dr=F){
 	n<-length(x[,1])
 	k<-length(x)/n
 	p0<-p0/k
@@ -47,8 +46,7 @@ fgr1st<-function(x,p0=0.01,km=0,kmx=0,nu=1,nedge=10^6,inr=T,dr=F){
 		double(km1),
 		as.integer(nedge),
 		double(kk),
-		as.integer(kk),
-		as.integer(kmx)
+		as.integer(kk)
 		)
 	ned<-tmp[[14]]
 	if(ned>0){
@@ -68,6 +66,7 @@ fgr1st<-function(x,p0=0.01,km=0,kmx=0,nu=1,nedge=10^6,inr=T,dr=F){
                 		ned<-tmp[[5]]
                 		edg<-tmp[[1]]
                 		edg<-matrix(edg,ncol=2)
+			edg<-edg[1:ned,]
         		}
     	}
     	else{
